@@ -1,8 +1,9 @@
 /* -*- Mode: C; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*- */
-/* $Id: memcached.h 512 2007-04-16 23:33:43Z plindner $ */
+/* $Id: memcached.h 570 2007-06-20 01:21:45Z plindner $ */
 
 #include "config.h"
 #include <sys/types.h>
+#include <sys/socket.h>
 #include <sys/time.h>
 #include <netinet/in.h>
 #include <event.h>
@@ -41,6 +42,11 @@
  typedef unsigned char             uint8_t;
 #endif
 
+/* unistd.h is here */
+#if HAVE_UNISTD_H
+# include <unistd.h>
+#endif
+
 /* Time relative to server start. Smaller than time_t on 64-bit systems. */
 typedef unsigned int rel_time_t;
 
@@ -102,7 +108,7 @@ typedef struct _stritem {
     uint8_t         it_flags;   /* ITEM_* above */
     uint8_t         slabs_clsid;/* which slab class we're in */
     uint8_t         nkey;       /* key length, w/terminating null and padding */
-    void * end[0];
+    void * end[];
     /* then null-terminated key */
     /* then " flags length\r\n" (no terminating null) */
     /* then data with terminating \r\n (no terminating null; it's binary!) */
@@ -213,7 +219,7 @@ conn *do_conn_from_freelist();
 int do_conn_add_to_freelist(conn *c);
 char *do_defer_delete(item *item, time_t exptime);
 void do_run_deferred_deletes(void);
-char *do_add_delta(item *item, int incr, unsigned int delta, char *buf);
+char *do_add_delta(item *item, int incr, const unsigned int delta, char *buf);
 int do_store_item(item *item, int comm);
 conn *conn_new(const int sfd, const int init_state, const int event_flags, const int read_buffer_size, const bool is_udp, struct event_base *base);
 
@@ -244,15 +250,15 @@ int  dispatch_event_add(int thread, conn *c);
 void dispatch_conn_new(int sfd, int init_state, int event_flags, int read_buffer_size, int is_udp);
 
 /* Lock wrappers for cache functions that are called from main loop. */
-char *mt_add_delta(item *item, int incr, unsigned int delta, char *buf);
+char *mt_add_delta(item *item, const int incr, const unsigned int delta, char *buf);
+void mt_assoc_move_next_bucket(void);
 conn *mt_conn_from_freelist(void);
 int   mt_conn_add_to_freelist(conn *c);
 char *mt_defer_delete(item *it, time_t exptime);
 int   mt_is_listen_thread(void);
 item *mt_item_alloc(char *key, size_t nkey, int flags, rel_time_t exptime, int nbytes);
 void  mt_item_flush_expired(void);
-item *mt_item_get_notedeleted(char *key, size_t nkey, bool *delete_locked);
-item *mt_item_get_nocheck(char *key, size_t nkey);
+item *mt_item_get_notedeleted(const char *key, const size_t nkey, bool *delete_locked);
 int   mt_item_link(item *it);
 void  mt_item_remove(item *it);
 int   mt_item_replace(item *it, item *new_it);
@@ -276,7 +282,6 @@ int   mt_store_item(item *item, int comm);
 # define is_listen_thread()          mt_is_listen_thread()
 # define item_alloc(x,y,z,a,b)       mt_item_alloc(x,y,z,a,b)
 # define item_flush_expired()        mt_item_flush_expired()
-# define item_get_nocheck(x,y)       mt_item_get_nocheck(x,y)
 # define item_get_notedeleted(x,y,z) mt_item_get_notedeleted(x,y,z)
 # define item_link(x)                mt_item_link(x)
 # define item_remove(x)              mt_item_remove(x)
@@ -305,7 +310,6 @@ int   mt_store_item(item *item, int comm);
 # define is_listen_thread()          1
 # define item_alloc(x,y,z,a,b)       do_item_alloc(x,y,z,a,b)
 # define item_flush_expired()        do_item_flush_expired()
-# define item_get_nocheck(x,y)       do_item_get_nocheck(x,y)
 # define item_get_notedeleted(x,y,z) do_item_get_notedeleted(x,y,z)
 # define item_link(x)                do_item_link(x)
 # define item_remove(x)              do_item_remove(x)
